@@ -130,9 +130,9 @@ def archive(conf):
             outputs.to_pickle(conf.OUTPUT_PATH)
     if not conf.NO_WRITE and conf.OUTPUT_EXT == ".csv":
         if conf.COMPRESS:
-            outputs.to_csv(conf.OUTPUT_PATH + ".csv.zip", escapechar='\\',compression="zip")
+            outputs.to_csv(conf.OUTPUT_PATH + ".zip", escapechar='\\',compression="zip")
         else:
-            outputs.to_csv(conf.OUTPUT_PATH + ".csv", escapechar='\\')
+            outputs.to_csv(conf.OUTPUT_PATH, escapechar='\\')
     if not conf.NO_WRITE and conf.OUTPUT_EXT == ".parquet":
         if conf.COMPRESS:
             outputs.to_parquet(conf.OUTPUT_PATH + ".parquet", compression="brotli")
@@ -231,17 +231,21 @@ def fees(conf):
             b['CaseNumber'] = b['CaseInfoOutputs'].map(lambda x: x[0])
             b['FeeOutputs'] = b.index.map(lambda x: getFeeSheet(str(b.loc[x].AllPagesText)))
             feesheet = b['FeeOutputs'].map(lambda x: x[6])
-
+            try:
+                feesheet['AmtDue'] = feesheet['AmtDue'].map(lambda x: pd.to_numeric(x, 'coerce'))
+                feesheet['AmtPaid'] = feesheet['AmtPaid'].map(lambda x: pd.to_numeric(x, 'coerce'))
+                feesheet['Balance'] = feesheet['Balance'].map(lambda x: pd.to_numeric(x, 'coerce'))
+                feesheet['AmtHold'] = feesheet['AmtHold'].map(lambda x: pd.to_numeric(x, 'coerce'))
+            except:
+                pass
+            
             feesheet = feesheet.dropna()
             fees = fees.dropna()
             feesheet = feesheet.tolist()  # -> [df, df, df]
             feesheet = pd.concat(feesheet, axis=0, ignore_index=True)
             fees = fees.append(feesheet, ignore_index=True)
             fees.fillna('', inplace=True)
-            fees['AmtDue'] = fees['AmtDue'].map(lambda x: pd.to_numeric(x, 'coerce'))
-            fees['AmtPaid'] = fees['AmtPaid'].map(lambda x: pd.to_numeric(x, 'coerce'))
-            fees['Balance'] = fees['Balance'].map(lambda x: pd.to_numeric(x, 'coerce'))
-            fees['AmtHold'] = fees['AmtHold'].map(lambda x: pd.to_numeric(x, 'coerce'))
+
     if not conf.NO_WRITE:
         write(conf, fees)
     complete(conf)
@@ -389,17 +393,21 @@ def cases(conf):
             chargetabs = pd.concat(chargetabs, axis=0, ignore_index=True)
 
             charges = charges.append(chargetabs, ignore_index=True)
-
-            feesheet['AmtDue'] = feesheet['AmtDue'].map(lambda x: pd.to_numeric(x, 'coerce'))
-            feesheet['AmtPaid'] = feesheet['AmtPaid'].map(lambda x: pd.to_numeric(x, 'coerce'))
-            feesheet['Balance'] = feesheet['Balance'].map(lambda x: pd.to_numeric(x, 'coerce'))
-            feesheet['AmtHold'] = feesheet['AmtHold'].map(lambda x: pd.to_numeric(x, 'coerce'))
-
-            b['ChargesTable'] = b['ChargesOutputs'].map(lambda x: x[-1])
-            b['Phone'] = b['Phone'].map(lambda x: pd.to_numeric(x, 'coerce'))
-            b['TotalAmtDue'] = b['TotalAmtDue'].map(lambda x: pd.to_numeric(x, 'coerce'))
-            b['TotalBalance'] = b['TotalBalance'].map(lambda x: pd.to_numeric(x, 'coerce'))
-            b['PaymentToRestore'] = b['TotalBalance'].map(lambda x: pd.to_numeric(x, 'coerce'))
+            try:
+                feesheet['AmtDue'] = feesheet['AmtDue'].map(lambda x: pd.to_numeric(x, 'coerce'))
+                feesheet['AmtPaid'] = feesheet['AmtPaid'].map(lambda x: pd.to_numeric(x, 'coerce'))
+                feesheet['Balance'] = feesheet['Balance'].map(lambda x: pd.to_numeric(x, 'coerce'))
+                feesheet['AmtHold'] = feesheet['AmtHold'].map(lambda x: pd.to_numeric(x, 'coerce'))
+            except:
+                pass
+            try:
+                b['ChargesTable'] = b['ChargesOutputs'].map(lambda x: x[-1])
+                b['Phone'] = b['Phone'].map(lambda x: pd.to_numeric(x, 'coerce'))
+                b['TotalAmtDue'] = b['TotalAmtDue'].map(lambda x: pd.to_numeric(x, 'coerce'))
+                b['TotalBalance'] = b['TotalBalance'].map(lambda x: pd.to_numeric(x, 'coerce'))
+                b['PaymentToRestore'] = b['TotalBalance'].map(lambda x: pd.to_numeric(x, 'coerce'))
+            except:
+                pass
 
             if bool(conf.OUTPUT_PATH) and len(conf.OUTPUT_EXT) > 2 and i > 0 and not conf.NO_WRITE:
                 if os.path.getsize(conf.OUTPUT_PATH) > 1000:
@@ -573,11 +581,13 @@ def caseinfo(conf):
             b['FeeCodesOwed'] = b['FeeOutputs'].map(lambda x: x[3])
             b['FeeCodes'] = b['FeeOutputs'].map(lambda x: x[4])
             b['FeeSheet'] = b['FeeOutputs'].map(lambda x: x[5])
-
-            b['Phone'] = b['Phone'].map(lambda x: pd.to_numeric(x, 'coerce'))
-            b['TotalAmtDue'] = b['TotalAmtDue'].map(lambda x: pd.to_numeric(x, 'coerce'))
-            b['TotalBalance'] = b['TotalBalance'].map(lambda x: pd.to_numeric(x, 'coerce'))
-            b['PaymentToRestore'] = b['TotalBalance'].map(lambda x: pd.to_numeric(x, 'coerce'))
+            try:
+                b['Phone'] = b['Phone'].map(lambda x: pd.to_numeric(x, 'coerce'))
+                b['TotalAmtDue'] = b['TotalAmtDue'].map(lambda x: pd.to_numeric(x, 'coerce'))
+                b['TotalBalance'] = b['TotalBalance'].map(lambda x: pd.to_numeric(x, 'coerce'))
+                b['PaymentToRestore'] = b['TotalBalance'].map(lambda x: pd.to_numeric(x, 'coerce'))
+            except:
+                pass
 
             if bool(conf.OUTPUT_PATH) and len(conf.OUTPUT_EXT) > 2 and i > 0 and not conf.NO_WRITE:
                 if os.path.getsize(conf.OUTPUT_PATH) > 1000:
@@ -807,7 +817,7 @@ def setinputs(path, debug=False):
             nzpath = path.replace(".zip","")
             nozipext = os.path.splitext(nzpath)[1]
             if debug:
-                click.echo(f"NZPATH: {nozipext}, NOZIPEXT: {nozipext}, PATH: {output_path}")
+                click.echo(f"NZPATH: {nozipext}, NOZIPEXT: {nozipext}, PATH: {path}")
             if nozipext == ".json":
                 pickle = pd.read_json(path, orient='table',compression="zip")
                 queue = pickle['AllPagesText']
@@ -1067,7 +1077,18 @@ def setpaths(input_path, output_path=None, count=0, table='', overwrite=False, l
     return c
 
 def setinit(input_path, output_path=None, archive=False,count=0, table='', overwrite=False, log=True, dedupe=False, no_write=False, no_prompt=False, debug=False, no_batch=False, compress=False):
-    a = setpaths(input_path=input_path, output_path=output_path, archive=archive, count=count, table=table, overwrite=overwrite, log=log, dedupe=dedupe, no_write=no_write, no_prompt=no_prompt,debug=debug, no_batch=no_batch, compress=compress)
+
+    if not isinstance(input_path, pd.core.series.Series) and input_path != None:
+        input_path = setinputs(input_path)
+
+    if not isinstance(output_path, pd.core.series.Series) and output_path != None:
+        output_path = setoutputs(output_path)
+
+    a = set(input_path, output_path, count=count, table=table, overwrite=overwrite, log=log, dedupe=dedupe, no_write=no_write, no_prompt=no_prompt,debug=debug, no_batch=no_batch, compress=compress)
+    
+    if archive == True:
+        a.MAKE = "archive"
+    
     b = init(a)
     return b
 
@@ -1380,10 +1401,12 @@ def getTotals(text: str):
         tdue = totalrow.split("$")[1].strip().replace("$", "").replace(",", "").replace(" ", "")
         tpaid = totalrow.split("$")[2].strip().replace("$", "").replace(",", "").replace(" ", "")
         thold = totalrow.split("$")[4].strip().replace("$", "").replace(",", "").replace(" ", "")
-        tdue = pd.to_numeric(tdue, 'coerce')
-        tpaid = pd.to_numeric(tpaid, 'coerce')
-        thold = pd.to_numeric(thold, 'coerce')
-
+        try:
+            tdue = pd.to_numeric(tdue, 'coerce')
+            tpaid = pd.to_numeric(tpaid, 'coerce')
+            thold = pd.to_numeric(thold, 'coerce')
+        except:
+            pass
     except IndexError:
         totalrow = 0
         tdue = 0
